"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var assert = require("assert");
var util_1 = require("util");
var Logger = (function () {
    function Logger(opts) {
        this.options = {
            level: 4
        };
        if (opts) {
            if (opts.level) {
                this.options.level = opts.level;
            }
            this.options.handleLogEntry = opts.handleLogEntry;
        }
        assert.ok(typeof this.options.level === 'number', "level");
        assert.ok(this.options.level >= 1 && this.options.level <= 6, "level");
        if (!this.options.handleLogEntry) {
            this.options.stream = opts && opts.stream ? opts.stream : process.stdout;
        }
    }
    Logger.prototype.fatal = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return this.log("FATAL", args);
    };
    Logger.prototype.error = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return this.log("ERROR", args);
    };
    Logger.prototype.warn = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return this.log("WARN", args);
    };
    Logger.prototype.info = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return this.log("INFO", args);
    };
    Logger.prototype.debug = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return this.log("DEBUG", args);
    };
    Logger.prototype.trace = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return this.log("TRACE", args);
    };
    Logger.prototype.log = function (levelStr, args) {
        if (Logger[levelStr] > this.options.level) {
            return;
        }
        var message = util_1.format.apply(null, args);
        if (this.options.handleLogEntry) {
            this.options.handleLogEntry(levelStr, args);
        }
        else {
            this.options.stream.write('[' + new Date() + ']'
                + ' ' + levelStr
                + ' ' + message
                + '\n');
        }
    };
    Logger.FATAL = 1;
    Logger.ERROR = 2;
    Logger.WARN = 3;
    Logger.INFO = 4;
    Logger.DEBUG = 5;
    Logger.TRACE = 6;
    return Logger;
}());
exports.default = Logger;
