"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai = require("chai");
var should = chai.should();
var expect = chai.expect;
var streamtest = require('streamtest').v2;
var index_1 = require("./index");
describe('Logger', function () {
    var logger;
    var levelStr;
    var args;
    beforeEach(function () {
        setupLogger();
    });
    function setupLogger(level, handleLogEntry, stream) {
        if (level === void 0) { level = index_1.default.INFO; }
        levelStr = '';
        args = [];
        logger = new index_1.default({
            level: level,
            handleLogEntry: handleLogEntry === false ? undefined : function (ls, a) {
                levelStr = ls;
                args = a;
            },
            stream: stream
        });
    }
    function testResponse(ls, a) {
        expect(ls).to.equal(levelStr);
        expect(a).to.deep.equal(args);
    }
    describe('level', function () {
        it('should handle invalid level type', function () {
            // tslint:disable-next-line:no-unused-expression
            expect(function () {
                setupLogger(10);
            }).to.throw();
            expect(function () {
                setupLogger('some');
            }).to.throw();
        });
        it('should handle level filtering', function () {
            setupLogger(index_1.default.WARN);
            logger.info('i');
            testResponse('', []);
            setupLogger(index_1.default.WARN);
            logger.error('e');
            testResponse('ERROR', ['e']);
        });
    });
    describe('handleLogEntry', function () {
        it('should return all args', function () {
            logger.error('e', 1, 2);
            testResponse('ERROR', ['e', 1, 2]);
        });
    });
    describe('stream fallback', function () {
        it('should use provided stream if handleLogEntry not given', function (done) {
            var stream = streamtest.toText(function (err, txt) {
                expect(txt).to.be.an('string').which.includes('WARN w\n');
                done();
            });
            setupLogger(index_1.default.INFO, false, stream);
            logger.warn('w');
            setTimeout(function () {
                stream.end();
            }, 10);
        });
    });
});
